@@ -51,17 +51,17 @@ namespace Kwave
 	         const QString &uid);
 
 	/** Destructor */
-	virtual ~MenuList();
+        virtual ~MenuList() Q_DECL_OVERRIDE;
 
 	/**
 	 * Always returns true, as the nodes of this type are no branches.
 	 */
-	bool isBranch() const Q_DECL_OVERRIDE { return false; }
+        virtual bool isBranch() const Q_DECL_OVERRIDE { return false; }
 
 	/**
 	 * Removes all entries from the list menu.
 	 */
-	void clear() Q_DECL_OVERRIDE;
+        virtual void clear() Q_DECL_OVERRIDE;
 
 	/**
 	 * Inserts a new leaf node under the corresponding submenu.
@@ -73,7 +73,7 @@ namespace Kwave
 	 * @param uid unique id string (might be 0)
 	 * @return pointer to the new leaf node
 	 */
-	Kwave::MenuNode *insertLeaf(const QString &name,
+        virtual Kwave::MenuNode *insertLeaf(const QString &name,
 	                                    const QString &command,
 	                                    const QKeySequence &shortcut,
 	                                    const QString &uid) Q_DECL_OVERRIDE;
