@@ -45,16 +45,16 @@ namespace Kwave
 	NoiseDialog(QWidget *parent, Kwave::OverViewCache *overview_cache);
 
 	/** Destructor */
-	virtual ~NoiseDialog();
+        virtual ~NoiseDialog() Q_DECL_OVERRIDE;
 
 	/** Returns the parameters as string list */
-	QStringList params() Q_DECL_OVERRIDE;
+        virtual QStringList params() Q_DECL_OVERRIDE;
 
 	/** Sets the from a list of parameters */
-	void setParams(QStringList &params) Q_DECL_OVERRIDE;
+        virtual void setParams(QStringList &params) Q_DECL_OVERRIDE;
 
 	/** retruns a pointer to this as a QDialog */
-	QDialog *dialog() Q_DECL_OVERRIDE { return this; }
+        virtual QDialog *dialog() Q_DECL_OVERRIDE { return this; }
 
     signals:
 
